@@ -28,17 +28,18 @@ extern "C" {
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdint.h>
+#include <sys/types.h>
 
 /**
  * LIBFDISK_VERSION:
  *
  * Library version string
  */
-#define LIBFDISK_VERSION   "2.32.0"
+#define LIBFDISK_VERSION   "2.33.2"
 
 #define LIBFDISK_MAJOR_VERSION   2
-#define LIBFDISK_MINOR_VERSION   32
-#define LIBFDISK_PATCH_VERSION   0
+#define LIBFDISK_MINOR_VERSION   33
+#define LIBFDISK_PATCH_VERSION   2
 
 /**
  * fdisk_context:
@@ -231,8 +232,12 @@ fdisk_sector_t fdisk_set_first_lba(struct fdisk_context *cxt, fdisk_sector_t lba
 fdisk_sector_t fdisk_get_last_lba(struct fdisk_context *cxt);
 fdisk_sector_t fdisk_set_last_lba(struct fdisk_context *cxt, fdisk_sector_t lba);
 fdisk_sector_t fdisk_get_nsectors(struct fdisk_context *cxt);
+
 const char *fdisk_get_devname(struct fdisk_context *cxt);
 int fdisk_get_devfd(struct fdisk_context *cxt);
+dev_t fdisk_get_devno(struct fdisk_context *cxt);
+const char *fdisk_get_devmodel(struct fdisk_context *cxt);
+
 
 unsigned int fdisk_get_geom_heads(struct fdisk_context *cxt);
 fdisk_sector_t fdisk_get_geom_sectors(struct fdisk_context *cxt);
@@ -794,6 +799,7 @@ int fdisk_ask_number_set_result(struct fdisk_ask *ask, uint64_t result);
 uint64_t fdisk_ask_number_get_base(struct fdisk_ask *ask);
 uint64_t fdisk_ask_number_get_unit(struct fdisk_ask *ask);
 int fdisk_ask_number_set_relative(struct fdisk_ask *ask, int relative);
+int fdisk_ask_number_is_wrap_negative(struct fdisk_ask *ask);
 int fdisk_ask_number_inchars(struct fdisk_ask *ask);
 int fdisk_ask_partnum(struct fdisk_context *cxt, size_t *partnum, int wantnew);
 
